const unsigned char leftMotorA = 7;
const unsigned char leftMotorB = 8;

const unsigned char rightMotorA = 9;
const unsigned char rightMotorB = 10;

int leftSwitch = 6;
int rightSwitch = 11;

int leftLed = 4;
int rightLed = 12;

int readingLeftSwitch = LOW;     // the current reading from the left input pin
int readingRightSwitch= LOW;     // the current reading from the right input pin

// This function is run first when the microcontroller is turned on
void setup() {
  // Initialize the pins used to talk to the motors
  pinMode(leftMotorA, OUTPUT);
  pinMode(leftMotorB, OUTPUT);
  pinMode(rightMotorA, OUTPUT);
  pinMode(rightMotorB, OUTPUT);
  
  // Initialize the pins used to connect to the switches
  pinMode(leftSwitch, INPUT);
  pinMode(rightSwitch, INPUT);
  
  // Initialize the Leds used to display the switch status
  // This will help with debugging and will make it look cooler
  pinMode(leftLed, OUTPUT);
  pinMode(rightLed, OUTPUT);

  // Writing LOW to a motor pin instructs the L293D to connect its output to ground.
  digitalWrite(leftMotorA, LOW);
  digitalWrite(leftMotorB, LOW);
  digitalWrite(rightMotorA, LOW);
  digitalWrite(rightMotorB, LOW);
  
  // Make the 'eyes' blink back and forth on start up.
  digitalWrite(leftLed, HIGH);
  delay(1000);
  digitalWrite(leftLed, LOW);
  digitalWrite(rightLed, HIGH);
  delay(1000);
  digitalWrite(rightLed, LOW);
  digitalWrite(leftLed, HIGH);
  delay(1000);
  digitalWrite(leftLed, LOW);
  digitalWrite(rightLed, HIGH);
  delay(1000);
  digitalWrite(rightLed, LOW);
  
  // Then, make the wheels move back and forth 
  // Point them in opposite directions, so the robot spins clockwise
  digitalWrite(leftMotorA, LOW);
  digitalWrite(leftMotorB, HIGH);
  digitalWrite(rightMotorA, HIGH);
  digitalWrite(rightMotorB, LOW);
  delay(1000); // Wait 1 second
  
  // Point them in opposite directions, so the robot spins counter clockwise
  digitalWrite(leftMotorA, HIGH);
  digitalWrite(leftMotorB, LOW);
  digitalWrite(rightMotorA, LOW);
  digitalWrite(rightMotorB, HIGH);
  delay(1000); // Wait 1 second
  
  // Time to start moving.....Turn both motors on, in the 'forward' direction
  digitalWrite(leftMotorA, LOW);
  digitalWrite(leftMotorB, HIGH);
  digitalWrite(rightMotorA, LOW);
  digitalWrite(rightMotorB, HIGH);
  delay(1000);  // Wait 1 second
}

// This function gets called repeatedly while the microcontroller is on.
void loop() {  
  
   // check the value of the bumper switches
   readingLeftSwitch = digitalRead(leftSwitch);
   readingRightSwitch = digitalRead(rightSwitch);
  
  if (readingLeftSwitch == HIGH) {
    digitalWrite (leftLed, HIGH);
    if (readingRightSwitch == HIGH) {
      digitalWrite(rightLed, HIGH);
      // both sensors touching, need to backup
      
      // Turn both motors on, in the 'backward' direction   
     digitalWrite(leftMotorA, HIGH);
     digitalWrite(leftMotorB, LOW);
     digitalWrite(rightMotorA, HIGH);
     digitalWrite(rightMotorB, LOW);
     delay(1000); // Wait 1 second
     
     // Turn off Leds
     digitalWrite(leftLed, LOW);
     digitalWrite(rightLed, LOW);

     // Point them in opposite directions, so the robot spins clockwise
     digitalWrite(leftMotorA, LOW);
     digitalWrite(leftMotorB, HIGH);
     digitalWrite(rightMotorA, HIGH);
     digitalWrite(rightMotorB, LOW);
     delay(1000); //Wait 1 second
     
     // Now go forward again - done at the end of the if statement

    } else { // backup to the right
     // Point them in opposite directions, so the robot spins counter clockwise
     digitalWrite(leftMotorA, HIGH);
     digitalWrite(leftMotorB, LOW);
     digitalWrite(rightMotorA, LOW);
     digitalWrite(rightMotorB, HIGH);
     delay(1000); //Wait 1 second
     
     // Turn off Led
     digitalWrite(leftLed, LOW);
     
     // Now go forward again - done at the end of the if statement

    }
  } else { // readingLeftSwitch is Low
     if (readingRightSwitch == HIGH) {
     digitalWrite(rightLed, HIGH);
     
     // Point them in opposite directions, so the robot spins clockwise
     digitalWrite(leftMotorA, LOW);
     digitalWrite(leftMotorB, HIGH);
     digitalWrite(rightMotorA, HIGH);
     digitalWrite(rightMotorB, LOW);

     // Wait 1 second
     delay(1000);
          
     // Turn off Led
     digitalWrite(rightLed, LOW);
     
     // Now go forward again - done at the end of the if statement
     }
  }
  // Continue moving forward  .....Turn both motors on, in the 'forward' direction
  digitalWrite(leftMotorA, LOW);
  digitalWrite(leftMotorB, HIGH);
  digitalWrite(rightMotorA, LOW);
  digitalWrite(rightMotorB, HIGH);
  delay(1000);   // Move forward one second and loop again
}